# The Schema-Guided Dialogue Dataset

Originally from the
[Google Research
Datasets](https://github.com/google-research-datasets/dstc8-schema-guided-dialogue/blob/master/README.md).
See that page for details.

This has two custom splits: one where Messaging, Payments, Home Search, and Rental Cars have also been fully extracted out of Google SGD (but is otherwise the same) and one that includes these extracted domains.
